==> lutool-boot-1.0.2-sources.jar: net/dreamlu/boot/config/LocaleConfiguration.java <==
package net.dreamlu.boot.config;

import net.dreamlu.boot.properties.DreamProperties;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.SearchStrategy;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.LocaleResolver;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;
import org.springframework.web.servlet.i18n.CookieLocaleResolver;
import org.springframework.web.servlet.i18n.LocaleChangeInterceptor;

import java.util.Locale;

/**
 * 国际化配置
 *
 * @author L.cm
 */
@Configuration
public class LocaleConfiguration extends WebMvcConfigurerAdapter {

	private final DreamProperties dreamProperties;

	public LocaleConfiguration(DreamProperties dreamProperties) {
		this.dreamProperties = dreamProperties;
	}

	@Bean
	@ConditionalOnMissingBean(value = LocaleResolver.class, search = SearchStrategy.CURRENT)
	public LocaleResolver localeResolver() {
		CookieLocaleResolver localeResolver = new CookieLocaleResolver();
		localeResolver.setDefaultLocale(dreamProperties.getLocale().getDefaultLocale());
		localeResolver.setCookieName(dreamProperties.getLocale().getCookieName());
		return localeResolver;
	}

	@Override
	public void addInterceptors(InterceptorRegistry registry) {
		LocaleChangeInterceptor localeChangeInterceptor = new LocaleChangeInterceptor();
		localeChangeInterceptor.setParamName(dreamProperties.getLocale().getParamName());
		registry.addInterceptor(localeChangeInterceptor);
	}
}

==> lutool-boot-1.0.4-sources.jar: net/dreamlu/boot/config/LocaleConfiguration.java <==
/*
 * *************************************************************************
 *   Copyright (c) 2018-2025, dreamlu.net All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the dreamlu.net developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: chunmeng.lu (qq596392912@gmail.com)
 * *************************************************************************
 */

package net.dreamlu.boot.config;

import lombok.AllArgsConstructor;
import net.dreamlu.boot.properties.DreamProperties;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.SearchStrategy;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.LocaleResolver;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;
import org.springframework.web.servlet.i18n.CookieLocaleResolver;
import org.springframework.web.servlet.i18n.LocaleChangeInterceptor;

import java.util.Locale;

/**
 * 国际化配置
 *
 * @author L.cm
 */
@Configuration
@AllArgsConstructor
public class LocaleConfiguration extends WebMvcConfigurerAdapter {
	private final DreamProperties dreamProperties;

	@Bean
	@ConditionalOnMissingBean(value = LocaleResolver.class, search = SearchStrategy.CURRENT)
	public LocaleResolver localeResolver() {
		CookieLocaleResolver localeResolver = new CookieLocaleResolver();
		localeResolver.setDefaultLocale(dreamProperties.getLocale().getDefaultLocale());
		localeResolver.setCookieName(dreamProperties.getLocale().getCookieName());
		return localeResolver;
	}

	@Override
	public void addInterceptors(InterceptorRegistry registry) {
		LocaleChangeInterceptor localeChangeInterceptor = new LocaleChangeInterceptor();
		localeChangeInterceptor.setParamName(dreamProperties.getLocale().getParamName());
		registry.addInterceptor(localeChangeInterceptor);
	}
}
